summaryrefslogtreecommitdiff
path: root/fml/lib/FML/CGI
diff options
context:
space:
mode:
authorfukachan <fukachan>2004-01-01 08:41:33 +0000
committerfukachan <fukachan>2004-01-01 08:41:33 +0000
commit93677afd30e299ef5c27cb1737d7f0dd20ccb196 (patch)
tree133358272028ba2e081d5c7df0efcd4d55c4d452 /fml/lib/FML/CGI
parent182d9ae3bf62ee6fb6316190b3758f874b725c00 (diff)
downloadfml8-93677afd30e299ef5c27cb1737d7f0dd20ccb196.tar.gz
fml8-93677afd30e299ef5c27cb1737d7f0dd20ccb196.tar.bz2
fml8-93677afd30e299ef5c27cb1737d7f0dd20ccb196.zip
update comments
Diffstat (limited to 'fml/lib/FML/CGI')
-rw-r--r--fml/lib/FML/CGI/Calendar.pm31
1 files changed, 27 insertions, 4 deletions
diff --git a/fml/lib/FML/CGI/Calendar.pm b/fml/lib/FML/CGI/Calendar.pm
index 23dcac7d..963dab56 100644
--- a/fml/lib/FML/CGI/Calendar.pm
+++ b/fml/lib/FML/CGI/Calendar.pm
@@ -4,7 +4,7 @@
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: Calendar.pm,v 1.4 2003/08/29 15:33:55 fukachan Exp $
+# $FML: Calendar.pm,v 1.5 2003/10/15 08:16:23 fukachan Exp $
#
package FML::CGI::Calendar;
@@ -43,10 +43,18 @@ Almost all methods inherit C<FML::Process::CGI> base class.
=head1 METHODS
+=head2 html_start()
+
+print out HTML header + body former part and navigator.
+
+=head2 html_end()
+
+print out the navigator and closing of html.
+
=cut
# Descriptions: print out HTML header + body former part
# Arguments: OBJ($curproc) HASH_REF($args)
# Side Effects: none
# Return Value: none
@@ -72,7 +80,7 @@ sub html_start
}
-# Descriptions: print out body latter part
+# Descriptions: print out the navigator and closing of html.
# Arguments: OBJ($curproc) HASH_REF($args)
# Side Effects: none
# Return Value: none
@@ -104,7 +112,22 @@ sub _show_guide
}
-# Descriptions: main routine for calendar as HTML TABLE format
+=head2 run_cgi_main()
+
+main routine to print calendar as HTML TABLE format.
+
+=head2 run_cgi_navigator()
+
+dummy.
+
+=head2 run_cgi_options()
+
+dummy.
+
+=cut
+
+
+# Descriptions: main routine to print calendar as HTML TABLE format.
# Arguments: OBJ($curproc) HASH_REF($args)
# Side Effects: none
# Return Value: none
@@ -43,10 +43,18 @@ Almost all methods inherit C<FML::Process::CGI> base class.
=cut
-# Descriptions: print out HTML header + body former part
+# Descriptions: print out HTML header + body former part and navigator.
# Arguments: OBJ($curproc) HASH_REF($args)
# Side Effects: none